@@ -127,6 +127,15 @@ cb_set_qrcode (GtkMenuItem *mi, const GdkPixbuf *pixbuf)
 }
 #endif
 
+static void
+cb_set_clipboard_from_primary (GtkMenuItem *mi)
+{
+  GtkClipboard *clipboard;
+
+  clipboard = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
+  gtk_clipboard_set_text (clipboard, gtk_menu_item_get_label (mi), -1);
+}
+
 static void
 cb_set_clipboard (GtkMenuItem *mi, const ClipmanHistoryItem *item)
 {
@@ -319,6 +328,7 @@ _clipman_menu_adjust_geometry (ClipmanMenu *menu)
 static void
 _clipman_menu_update_list (ClipmanMenu *menu)
 {
+  GtkClipboard *clipboard;
   GtkWidget *mi, *image;
 #ifdef HAVE_QRENCODE
   GdkPixbuf *pixbuf;
@@ -327,7 +337,10 @@ _clipman_menu_update_list (ClipmanMenu *menu)
   const ClipmanHistoryItem *item_to_restore;
   GSList *list, *l;
   gint pos = 0;
-  gint i = 0;
+  guint i = 0;
+  gchar *selection_primary;
+  gchar *selection_clipboard;
+  gboolean skip_primary = FALSE;
 
   /* Get the most recent item in the history */
   item_to_restore = clipman_history_get_item_to_restore (menu->priv->history);
@@ -342,6 +355,13 @@ _clipman_menu_update_list (ClipmanMenu *menu)
   list = clipman_history_get_list (menu->priv->history);
   if (menu->priv->reverse_order)
     list = g_slist_reverse (list);
+
+  clipboard = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
+  selection_clipboard = gtk_clipboard_wait_for_text (clipboard);
+
+  clipboard = gtk_clipboard_get (GDK_SELECTION_PRIMARY);
+  selection_primary = gtk_clipboard_wait_for_text (clipboard);
+
   for (i = 0, l = list; i < menu->priv->max_menu_items; i++, l = l->next)
     {
       if (l == NULL)
@@ -372,13 +392,37 @@ G_GNUC_END_IGNORE_DEPRECATIONS
       g_signal_connect (mi, "activate", G_CALLBACK (cb_set_clipboard), item);
       g_object_set_data (G_OBJECT (mi), "paste-on-activate", GUINT_TO_POINTER (menu->priv->paste_on_activate));
 
-      if (item == item_to_restore)
+      if (selection_clipboard && (item->type == CLIPMAN_HISTORY_TYPE_TEXT)
+          && (g_strcmp0 (selection_clipboard, item->content.text) == 0))
         {
-          image = gtk_image_new_from_icon_name ("go-next-symbolic", GTK_ICON_SIZE_MENU);
+          image = gtk_image_new_from_icon_name ("edit-paste-symbolic",
+                                                GTK_ICON_SIZE_MENU);
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-          gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mi), image);
+          gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM(mi), image);
 G_GNUC_END_IGNORE_DEPRECATIONS
         }
+      else
+        if (selection_primary && (item->type == CLIPMAN_HISTORY_TYPE_TEXT)
+            && (g_strcmp0 (selection_primary, item->content.text) == 0))
+          {
+            image = gtk_image_new_from_icon_name ("input-mouse-symbolic",
+                                                  GTK_ICON_SIZE_MENU);
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+            gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM(mi), image);
+  G_GNUC_END_IGNORE_DEPRECATIONS
+          }
+        else
+          /* not sure if "item_to_restore" can be neither primary nor clipboard...
+           * but let's leave this as fallback
+           */
+          if (item == item_to_restore)
+            {
+              image = gtk_image_new_from_icon_name ("go-next-symbolic",
+                                            GTK_ICON_SIZE_MENU);
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+              gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM(mi), image);
+G_GNUC_END_IGNORE_DEPRECATIONS
+            }
 
       menu->priv->list = g_slist_prepend (menu->priv->list, mi);
       gtk_menu_shell_insert (GTK_MENU_SHELL (menu), mi, pos++);
@@ -432,6 +476,30 @@ G_GNUC_END_IGNORE_DEPRECATIONS
       gtk_widget_set_sensitive (menu->priv->mi_clear_history, FALSE);
     }
 
+  /* Show the primary clipboard item so it can be selected for keyboard pasting
+   * even if "ignore selection" is enabled!
+   */
+  if (selection_primary)
+    {
+      skip_primary = (g_strcmp0 (selection_primary, selection_clipboard) == 0) ||
+      (item_to_restore && (item_to_restore->type == CLIPMAN_HISTORY_TYPE_TEXT) && g_strcmp0 (selection_primary, item_to_restore->content.text) == 0);
+
+      if (skip_primary == FALSE)
+        {
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+          mi = gtk_image_menu_item_new_with_label (selection_primary);
+          image = gtk_image_new_from_icon_name ("input-mouse-symbolic", GTK_ICON_SIZE_MENU);
+          gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mi), image);
+G_GNUC_END_IGNORE_DEPRECATIONS
+          gtk_menu_shell_insert (GTK_MENU_SHELL (menu), mi, 0);
+          gtk_widget_show_all (mi);
+          g_signal_connect (mi, "activate", G_CALLBACK (cb_set_clipboard_from_primary), NULL);
+          menu->priv->list = g_slist_prepend (menu->priv->list, mi);
+        }
+      g_free (selection_primary);
+    }
+  g_free (selection_clipboard);
+
   _clipman_menu_adjust_geometry(menu);
 }
 
