@@ -87,6 +87,7 @@ plugin_register (void)
   if (g_application_get_is_remote (G_APPLICATION (plugin->app)))
     {
       g_message ("Primary instance org.xfce.clipman already running");
+      clipman_common_show_info_dialog ();
       g_object_unref (plugin->app);
       return FALSE;
     }
@@ -131,6 +132,8 @@ plugin_register (void)
   xfconf_g_property_bind (plugin->channel, "/settings/show-qr-code",
                           G_TYPE_BOOLEAN, plugin->menu, "show-qr-code");
 #endif
+  xfconf_g_property_bind (plugin->channel, "/tweaks/max-menu-items",
+                          G_TYPE_UINT, plugin->menu, "max-menu-items");
   xfconf_g_property_bind (plugin->channel, "/tweaks/reverse-menu-order",
                           G_TYPE_BOOLEAN, plugin->menu, "reverse-order");
   xfconf_g_property_bind (plugin->channel, "/tweaks/paste-on-activate",
@@ -189,7 +192,6 @@ plugin_load (MyPlugin *plugin)
       texts = g_key_file_get_string_list (keyfile, "texts", "texts", NULL, NULL);
       for (i = 0; texts != NULL && texts[i] != NULL; i++)
         clipman_history_add_text (plugin->history, texts[i]);
-      g_unlink (filename);
     }
 
   g_key_file_free (keyfile);
@@ -311,7 +313,7 @@ plugin_free (MyPlugin *plugin)
 void
 plugin_about (MyPlugin *plugin)
 {
-  const gchar *authors[] = { "(c) 2014-2016 Simon Steinbeiss",
+  const gchar *authors[] = { "(c) 2014-2020 Simon Steinbeiss",
                              "(c) 2008-2014 Mike Massonnet",
                              "(c) 2005-2006 Nick Schermer",
                              "(c) 2003 Eduard Roccatello",
