@@ -33,7 +33,6 @@
 #include "settings-dialog_ui.h"
 #include "actions.h"
 
-static void             prop_dialog_run                 ();
 static void             cb_show_help                    (GtkButton *button);
 static void             setup_actions_treeview          (GtkTreeView *treeview);
 static void             refresh_actions_treeview        (GtkTreeView *treeview);
@@ -47,22 +46,21 @@ static void             cb_actions_row_activated        (GtkTreeView *treeview,
 static void             cb_delete_action                (GtkButton *button);
 static void             cb_reset_actions                (GtkButton *button);
 static void             setup_commands_treeview         (GtkTreeView *treeview);
-static void             entry_dialog_cleanup            ();
+static void             entry_dialog_cleanup            (void);
 static void             cb_commands_selection_changed   (GtkTreeSelection *selection);
 static void             cb_add_command                  (GtkButton *button);
 static void             cb_refresh_command              (GtkButton *button);
 static void             cb_delete_command               (GtkButton *button);
-static void             setup_test_regex_dialog         ();
+static void             setup_test_regex_dialog         (void);
 static void             cb_test_regex                   (GtkButton *button);
 static void             cb_test_regex_changed           (GtkWidget *widget);
-static gboolean         cb_test_regex_changed_timeout   ();
 static gboolean         cb_regex_focus_in_event         (GtkWidget *widget,
                                                          GdkEvent  *event,
                                                          gpointer   user_data);
 static gboolean         cb_regex_focus_out_event        (GtkWidget *widget,
                                                          GdkEvent  *event,
                                                          gpointer   user_data);
-static void             update_test_regex_textview_tags ();
+static void             update_test_regex_textview_tags (void);
 static void             cb_set_action_dialog_button_ok  (GtkWidget *widget);
 
 static XfconfChannel *xfconf_channel = NULL;
@@ -229,13 +227,13 @@ prop_dialog_run (void)
 static void
 cb_show_help (GtkButton *button)
 {
-  gchar *locale = NULL;
-  gchar *offset;
   gchar *docpath = NULL;
   gchar *command = NULL;
 
   /* Find localized documentation path on disk */
 #ifdef ENABLE_NLS
+  gchar *locale = NULL;
+  gchar *offset;
 #ifdef HAVE_LOCALE_H
   locale = g_strdup (setlocale (LC_MESSAGES, ""));
   if (locale != NULL)
@@ -752,6 +750,14 @@ cb_test_regex (GtkButton *button)
   gtk_widget_hide (dialog);
 }
 
+static gboolean
+cb_test_regex_changed_timeout (gpointer user_data)
+{
+  update_test_regex_textview_tags ();
+  test_regex_changed_timeout = 0;
+  return FALSE;
+}
+
 static void
 cb_test_regex_changed (GtkWidget *widget)
 {
@@ -762,15 +768,7 @@ cb_test_regex_changed (GtkWidget *widget)
   if (test_regex_changed_timeout > 0)
     g_source_remove (test_regex_changed_timeout);
 
-  test_regex_changed_timeout = g_timeout_add_seconds (1, (GSourceFunc)cb_test_regex_changed_timeout, NULL);
-}
-
-static gboolean
-cb_test_regex_changed_timeout (void)
-{
-  update_test_regex_textview_tags ();
-  test_regex_changed_timeout = 0;
-  return FALSE;
+  test_regex_changed_timeout = g_timeout_add_seconds (1, cb_test_regex_changed_timeout, NULL);
 }
 
 static gboolean
