@@ -31,18 +31,13 @@
 /* Initial code was taken from xfwm4/src/menu.c:grab_available().
  * TODO replace deprecated GTK/GDK functions.
  */
-static gboolean
-grab_keyboard ()
+static void
+grab_keyboard (void)
 {
   guint32 timestamp = GDK_CURRENT_TIME;
   GdkScreen *screen = gdk_screen_get_default ();
   GdkWindow *win = gdk_screen_get_root_window (screen);
-  GdkEventMask mask =
-    GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
-    GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK |
-    GDK_POINTER_MOTION_MASK;
   GdkGrabStatus grab_status;
-  gboolean grab_failed = FALSE;
   gint i = 0;
 
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
